<img src="https://qwertyquerty.github.io/pypresence/html/_static/logosmall.svg" width="100%">

> A Discord RPC library in Python? Looks like you've come to the right place.

Written by: [qwertyquerty](https://github.com/qwertyquerty)

Notable Contributors: [GiovanniMCMXCIX](https://github.com/GiovanniMCMXCIX), [GhostofGoes](https://github.com/GhostofGoes)

[![GitHub stars](https://img.shields.io/github/stars/qwertyquerty/pypresence.svg?style=for-the-badge&label=Stars)](https://github.com/qwertyquerty/pypresence) [![license](https://img.shields.io/github/license/qwertyquerty/pypresence.svg?style=for-the-badge)](https://github.com/qwertyquerty/pypresence/blob/master/LICENSE) ![GitHub last commit](https://img.shields.io/github/last-commit/qwertyquerty/pypresence.svg?style=for-the-badge) ![GitHub top language](https://img.shields.io/github/languages/top/qwertyquerty/pypresence.svg?style=for-the-badge) ![PyPI](https://img.shields.io/pypi/v/pypresence.svg?style=for-the-badge)


## NOTICE: Activity() class has been removed in 4.0.0


### [Documentation](https://qwertyquerty.github.io/pypresence/html/index.html), [Discord Server](https://discord.gg/JF3kg77), [Patreon](https://www.patreon.com/qwertyquerty)

----------

**Use this badge in your project's Readme to show you're using pypresence! The markdown code is below.**

[![pypresence](https://img.shields.io/badge/using-pypresence-00bb88.svg?style=for-the-badge&logo=discord&logoWidth=20)](https://github.com/qwertyquerty/pypresence)

```markdown
[![pypresence](https://img.shields.io/badge/using-pypresence-00bb88.svg?style=for-the-badge&logo=discord&logoWidth=20)](https://github.com/qwertyquerty/pypresence)
```


----------

# Installation

Install pypresence with **`pip`**

For the latest development version:

### `pip install https://github.com/qwertyquerty/pypresence/archive/master.zip`

For the latest stable version:

### `pip install pypresence`

----------


# Documentation

> **NOTE**: You need an **authorized app** to do anything besides rich presence!

####  [pypresence Documentation](https://qwertyquerty.github.io/pypresence/html/index.html)
####  [Discord Rich Presence Documentation](https://discordapp.com/developers/docs/rich-presence/how-to)
####  [Discord RPC Documentation](https://discordapp.com/developers/docs/topics/rpc)
####  [pyresence Discord Support Server](https://discord.gg/JF3kg77)
####  [Discord API Support Server](https://discord.gg/discord-api)

----------

# Examples

Examples can be found in the [examples](https://github.com/qwertyquerty/pypresence/tree/master/examples) directory, and you can contribute your own examples if you wish, just read [examples.md](https://github.com/qwertyquerty/pypresence/blob/master/examples/examples.md)!
